import os
import json
from flask import json
from flask import jsonify
from flask import Flask
from flask import request
import queue
import time

app = Flask(__name__)
messageQueue = queue.Queue()
sessionMessages = {}
handler = None

@app.route("/")
def main():
    return "Personal Clara instance."

@app.route("/converse", methods=['POST'])
@app.route("/api/v1/send/<int:session_id>", methods=['POST'])
def parse_request(session_id=None):
    print('Session id: ' + str(session_id))
    try:
        text = json.dumps(request.json)
        message = request.json('input')
    except:
        message = request.form['input']
    print('User message: ' + message)
    message = message.lower()
    if session_id == None:
        messageQueue.put(message)
    else:
        try:
            sessionMessages[session_id].put(message)
        except:
            sessionMessages[session_id] = queue.Queue()
            sessionMessages[session_id].put(message)
    return json.dumps({ 'success': True })

@app.route("/getresponse", methods=['GET'])
@app.route("/api/v1/get/<int:session_id>", methods=['GET'])
def handle_retrieval(session_id=None):
    response = handler.get_response(session_id)
    if response['text'] == None:
        return '{"message": "None", "new": "false"}'
    else:
        return '{"message": "' + response['text'] + '", "new": "true"}'


@app.route('/api/v1/io/blocking/<int:session_id>', methods=['POST'])
@app.route('/api/v1/io/blocking', methods=['POST'])
def full_retreival(session_id=None):
    try:
        text = json.dumps(request.json)
        message = request.json('input')
    except:
        message = request.form['input']
    message = message.lower()
    if session_id == None:
        messageQueue.put(message)
    else:
        try:
            sessionMessages[session_id].put(message)
        except:
            sessionMessages[session_id] = queue.Queue()
            sessionMessages[session_id].put(message)
    toReturn = ""
    time.sleep(0.25)
    toQuit = False
    while not toQuit:
        response = handler.get_response(session_id)
        print(response)
        if response['text'] == None:
            toQuit = True
        else:
            toReturn += str(response['text']) + '\n'
    return '{"message": "' + toReturn + '", "new": "true"}'

def set_handler(obj):
    global handler
    handler = obj

if __name__ == "__main__":
    port = int(os.environ.get("PORT", 2525))
    app.run(host='0.0.0.0', port=port, debug=True)



import brain
import os
from flask import json
from flask import jsonify
from flask import Flask
from flask import request

app = Flask(__name__)

@app.route("/")
def main():
    return "Personal Clara instance."

def log(text, response):
    logFile = open('log.txt', 'a')
    ender = '\n'
    logFile.write('S: ' + text + ender)
    if not response == None:
        logFile.write('R: ' + response + ender)
    else:
        logFile.write('R: None' + ender)

@app.route("/converse", methods=['POST'])
def parse_request():
    try:
        text = json.dumps(request.json)
        message = request.json['input']
    except:
        message = request.form['input']
    message = message.lower()
    response = brain.get_response(message)
    # Logging i/o
    if not response == None:
        log(message, response['message'])
    else:
        log(message, None)
    if not response == None:
       to_return = '{"message": "' + response['message'] + '", "image": "' + response['image'] + '"}'
       return to_return
    else:
        return '{"message": "' + "Sorry! I'm still learning to understanding." + '"}'

if __name__ == "__main__":
    port = int(os.environ.get("PORT", 2525))
    app.run(host='0.0.0.0', port=port, debug=True)



def handle_modifiers(modifiers):
    for i in modifiers:
        VAR_REGISTRY[i['name']] += i['val']

def calc_qualifiers(qualifier):
    registryValue = VAR_REGISTRY[qualifier['name']]
    try:
        if registryValue > qualifier['$gt']:
            return True
        else:
            return False
    except:
        # Not a greater than qualifier
        doNothing = True
    try:
        if registryValue == qualifier['$eq']:
            return True
        else:
            return False
    except:
        # Not an equal to qualifier
        doNothing = True
    try:
        if regsitryValue < qualifier['$lt']:
            return True
        else:
            return False
    except:
        # Not a less than qualifier
        doNothing = True
    # Legacy qualifier types
    try:
        if registryValue == qualifier['val']:
            return True
        else:
            return False
    except:
        # Not a less than qualifier
        doNothing = True
    # if supplied info doesn't fit any of the above qualifier types reject
    return False



#from distutils.core import setup
from setuptools import setup
setup(
  name = 'clara',
  packages = ['clara','clara/utils'],
  package_data={'clara/utils':['*']},
  scripts=['bin/clara'],
  version = '1.1.1',
  description = 'Conversational chit-chat utility agent',
  author = 'Noah Huber-Feely',
  author_email = 'nhuberfeely@gmail.com',
  url = 'https://github.com/huberf/clara-pip', # use the URL to the github repo
  download_url = 'https://github.com/huberf/clara-pip/archive/1.1.1.tar.gz',
  keywords = ['clara', 'chat'], # arbitrary keywords
  classifiers = [],
)
